@@ -1,4 +1,4 @@
-VERSION = '0.0.10'
+VERSION = '0.1.0'
 
 ENDPOINT_AI = 'ai'
 ENDPOINT_HH = 'hh'
@@ -9,5 +9,7 @@ COMMAND_GET_COMMAND = 'getCommand'
 
 DEVICE_TYPE_UNKNOWN = 'UNKNOWN'
 DEVICE_TYPE_WASHING_MACHINE = 'WASHING_MACHINE'
+DEVICE_TYPE_DRYER = 'DRYER'
 
 MODEL_MATCH_WASHING_MACHINE = 'wash'
+MODEL_MATCH_DRYER = 'dry'
