@@ -1,11 +1,10 @@
-import re
-from typing import Dict, Any
-
-from .basic_device import BasicDevice, DeviceError
-from datetime import datetime, timedelta
-from .const import ENDPOINT_HH, COMMAND_GET_PROGRAM, COMMAND_GET_COMMAND
 import locale
 
+from datetime import datetime, timedelta
+from typing import Dict, Any
+from .basic_device import BasicDevice, DeviceError, read_kwh_from_string, read_float_from_string
+from .const import ENDPOINT_HH, COMMAND_GET_PROGRAM
+
 locale.setlocale(locale.LC_ALL, '')  # Use '' for auto, or force e.g. to 'en_US.UTF-8'
 
 COMMAND_VALUE_ECOM_STAT_TOTAL = 'ecomXstatXtotal'
@@ -26,7 +25,14 @@ PROGRAM_OPTIDOS_FILL_LEVEL_ACT = 'act'
 CONSUMPTION_DETAILS_VALUE = 'value'
 
 REGEX_MATCH_LITER = r"(\d+(?:[\,\.]\d+)?).?ℓ"
-REGEX_MATCH_KWH = r"(\d+(?:[\,\.]\d+)?).?kWh"
+
+
+def read_liter_from_string(consumption_value: str) -> float:
+    liter = read_float_from_string(consumption_value, REGEX_MATCH_LITER)
+    if liter < 0:
+        raise DeviceError('Cannot find liter value in string {0}'.format(consumption_value), 'n/a')
+
+    return liter
 
 
 class WashingMachine(BasicDevice):
@@ -133,29 +139,18 @@ class WashingMachine(BasicDevice):
         self._logger.info("optiDos information: %s optiDos A status: %s, optiDos B status: %s",
                           self._optidos_config, self.optidos_a_status, self.optidos_b_status)
 
-    async def _do_consumption_details_request(self, command: str) -> str:
-
-        url = self.get_command_url(ENDPOINT_HH, COMMAND_GET_COMMAND).update_query({'value': command})
-        eco_json = await self.make_vzug_device_call_json(url)
-
-        if CONSUMPTION_DETAILS_VALUE in eco_json:
-            return eco_json[CONSUMPTION_DETAILS_VALUE]
-        else:
-            self._logger.error('Error reading power and water consumption, no \'value\' entry found in response.')
-            raise DeviceError('Got invalid response while reading power and water consumption data.', 'n/a')
-
     async def load_consumption_data(self) -> bool:
         """Load power and water consumption data by calling the corresponding API endpoint"""
 
         self._logger.info("Loading power and water consumption data for %s", self._host)
         try:
-            consumption_total = await self._do_consumption_details_request(COMMAND_VALUE_ECOM_STAT_TOTAL)
-            self._power_consumption_kwh_total = self._read_kwh_from_string(consumption_total)
-            self._water_consumption_l_total = self._read_liter_from_string(consumption_total)
+            consumption_total = await self.do_consumption_details_request(COMMAND_VALUE_ECOM_STAT_TOTAL)
+            self._power_consumption_kwh_total = read_kwh_from_string(consumption_total)
+            self._water_consumption_l_total = read_liter_from_string(consumption_total)
 
-            consumption_avg = await self._do_consumption_details_request(COMMAND_VALUE_ECOM_STAT_AVG)
-            self._power_consumption_kwh_avg = self._read_kwh_from_string(consumption_avg)
-            self._water_consumption_l_avg = self._read_liter_from_string(consumption_avg)
+            consumption_avg = await self.do_consumption_details_request(COMMAND_VALUE_ECOM_STAT_AVG)
+            self._power_consumption_kwh_avg = read_kwh_from_string(consumption_avg)
+            self._water_consumption_l_avg = read_liter_from_string(consumption_avg)
 
             self._logger.info("Power consumption total: %s kWh, avg: %.1f kWh",
                               locale.format_string('%.0f', self._power_consumption_kwh_total, True),
@@ -173,28 +168,6 @@ class WashingMachine(BasicDevice):
 
         return True
 
-    @staticmethod
-    def _read_float_from_string(consumption_value: str, regex: str) -> float:
-        match = re.search(regex, consumption_value)
-        if match:
-            return float(match.group(1).replace(',', '.'))
-
-        return -1
-
-    def _read_liter_from_string(self, consumption_value: str) -> float:
-        liter = self._read_float_from_string(consumption_value, REGEX_MATCH_LITER)
-        if liter < 0:
-            raise DeviceError('Cannot find liter value in string {0}'.format(consumption_value), 'n/a')
-
-        return liter
-
-    def _read_kwh_from_string(self, consumption_value: str) -> float:
-        kwh = self._read_float_from_string(consumption_value, REGEX_MATCH_KWH)
-        if kwh < 0:
-            raise DeviceError('Cannot find kWh value in string {0}'.format(consumption_value), 'n/a')
-
-        return kwh
-
     @property
     def program_status(self) -> str:
         return self._program_status
